@@ -1,16 +1,18 @@
+import os
+
 from azure.storage.blob import BlobClient
 
 
-def read_jsonl(conn_str: str, container: str, blob: str,
-               attr: str = 'url', encoding: str = 'UTF-8',
+def read_jsonl(blob: str, attr: str = 'url', encoding: str = 'UTF-8',
                startswith: str = 'http') -> 'list[str]':
     """Reads all JSON Lines datasources from the specified blob and container."""
     attr = f'"{attr}": "'
     
     blob_client = BlobClient.from_connection_string(
-        conn_str=conn_str,
-        container_name=container, blob_name=blob
-    )
+        conn_str=os.environ['AzureWebJobsStorage'],
+        container_name=os.environ['AZCONTAINER_PATH'],
+        blob_name=blob,
+        logging_enable=True)
     
     stream = blob_client.download_blob()
     content, datasources = [], []
